pub struct NonMaxI32(/* private fields */);Expand description
An integer that is known not to equal its maximum value.
Implementations
Sourceimpl NonMaxI32
impl NonMaxI32
Sourcepub const MAX: NonMaxI32
pub const MAX: NonMaxI32
Gets non-max with maximum possible value (which is maximum of the underlying primitive minus one)
Sourcepub const fn new(value: i32) -> Option<Self>
pub const fn new(value: i32) -> Option<Self>
Creates a new non-max if the given value is not the maximum value.
Sourcepub const unsafe fn new_unchecked(value: i32) -> Self
pub const unsafe fn new_unchecked(value: i32) -> Self
Creates a new non-max without checking the value.
Safety
The value must not equal the maximum representable value for the primitive type.