pub struct NonMaxUsize(/* private fields */);Expand description
An integer that is known not to equal its maximum value.
Implementations
Sourceimpl NonMaxUsize
impl NonMaxUsize
Sourcepub const ZERO: NonMaxUsize
pub const ZERO: NonMaxUsize
Gets non-max with the value zero (0)
Sourcepub const ONE: NonMaxUsize
pub const ONE: NonMaxUsize
Gets non-max with the value one (1)
Sourcepub const MAX: NonMaxUsize
pub const MAX: NonMaxUsize
Gets non-max with maximum possible value (which is maximum of the underlying primitive minus one)
Sourcepub const fn new(value: usize) -> Option<Self>
pub const fn new(value: usize) -> Option<Self>
Creates a new non-max if the given value is not the maximum value.
Sourcepub const unsafe fn new_unchecked(value: usize) -> Self
pub const unsafe fn new_unchecked(value: usize) -> Self
Creates a new non-max without checking the value.
Safety
The value must not equal the maximum representable value for the primitive type.